==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/OperatorConditionBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorConditionBuilder extends io.fabric8.openshift.api.model.operator.v1.OperatorConditionFluentImpl<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.OperatorCondition,io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder>{
  public OperatorConditionBuilder() {
    this(false);
  }
  public OperatorConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorCondition(), validationEnabled);
  }
  public OperatorConditionBuilder(io.fabric8.openshift.api.model.operator.v1.OperatorConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorConditionBuilder(io.fabric8.openshift.api.model.operator.v1.OperatorConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorCondition(), validationEnabled);
  }
  public OperatorConditionBuilder(io.fabric8.openshift.api.model.operator.v1.OperatorConditionFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OperatorCondition instance) {
    this(fluent, instance, false);
  }
  public OperatorConditionBuilder(io.fabric8.openshift.api.model.operator.v1.OperatorConditionFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OperatorCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorConditionBuilder(io.fabric8.openshift.api.model.operator.v1.OperatorCondition instance) {
    this(instance,false);
  }
  public OperatorConditionBuilder(io.fabric8.openshift.api.model.operator.v1.OperatorCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.OperatorConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition build() {
    OperatorCondition buildable = new OperatorCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorConditionBuilder that = (OperatorConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.3.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/OperatorConditionBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OperatorConditionBuilder extends OperatorConditionFluentImpl<OperatorConditionBuilder> implements VisitableBuilder<OperatorCondition,OperatorConditionBuilder>{
  public OperatorConditionBuilder() {
    this(false);
  }
  public OperatorConditionBuilder(Boolean validationEnabled) {
    this(new OperatorCondition(), validationEnabled);
  }
  public OperatorConditionBuilder(OperatorConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorConditionBuilder(OperatorConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OperatorCondition(), validationEnabled);
  }
  public OperatorConditionBuilder(OperatorConditionFluent<?> fluent,OperatorCondition instance) {
    this(fluent, instance, false);
  }
  public OperatorConditionBuilder(OperatorConditionFluent<?> fluent,OperatorCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorConditionBuilder(OperatorCondition instance) {
    this(instance,false);
  }
  public OperatorConditionBuilder(OperatorCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  OperatorConditionFluent<?> fluent;
  Boolean validationEnabled;
  public OperatorCondition build() {
    OperatorCondition buildable = new OperatorCondition(fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
